@@ -7,22 +7,16 @@
 # DESCRIPTION:
 #   
 #
-#  $Id: Property.pm,v 1.5 2000/04/04 17:50:28 eric Exp $
+#  $Id: Property.pm,v 1.7 2000/05/24 04:41:32 eric Exp $
 #  $Locker:  $
 #
-# (C) COPYRIGHT 1999 Eric Busboom
-# http://www.softwarestudio.org 
+# (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
+#
+# This package is free software and is provided "as is" without express
+# or implied warranty.  It may be used, redistributed and/or modified
+# under the same terms as perl itself. ( Either the Artistic License or the
+# GPL. ) 
 #
-# The contents of this file are subject to the Mozilla Public License
-# Version 1.0 (the "License"); you may not use this file except in
-# compliance with the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-# 
-# Software distributed under the License is distributed on an "AS IS"
-# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
-# the License for the specific language governing rights and
-# limitations under the License.
-# 
 # The Original Code is Property.pm. The Initial Developer of the Original
 # Code is Eric Busboom
 #
@@ -100,6 +94,13 @@ sub as_ical_string{
 }
 
 sub type {
+  my $self = shift;
+  my $impl = $self->_impl();
+
+  my $type = Net::ICal::icalproperty_isa($impl);
+  
+  return Net::ICal::icalenum_property__kind_to_string($type);
+
 }
 
 sub isa_property{
